@@ -3,15 +3,13 @@ import io
 import logging
 import re
 import time
+import xml.etree.ElementTree as elementtree  # noqa: N813
 from collections import OrderedDict
 from contextlib import closing
 from urllib.parse import urlparse
 
 import requests
 
-import xml.etree.ElementTree as elementtree  # noqa: N813
-
-
 logger = logging.getLogger(__name__)
 
 
@@ -75,7 +73,7 @@ def parse_m3u(data):
 def parse_pls(data):
     # Copied from mopidy.audio.playlists
     try:
-        cp = configparser.RawConfigParser()
+        cp = configparser.RawConfigParser(strict=False)
         cp.read_string(data.decode())
     except configparser.Error:
         return
@@ -191,7 +189,7 @@ class TuneIn:
     ID_UNKNOWN = "unknown"
 
     def __init__(self, timeout, filter_=None, session=None):
-        self._base_uri = "http://opml.radiotime.com/%s"
+        self._base_uri = "https://opml.radiotime.com/%s"
         self._session = session or requests.Session()
         self._timeout = timeout / 1000.0
         if filter_ in [TuneIn.ID_PROGRAM, TuneIn.ID_STATION]:
